@@ -6,6 +6,7 @@ from django.http import Http404
 from django.utils import six
 
 from floraconcierge import shortcuts
+from floraconcierge.apiauth.models import User
 from floraconcierge.cache import get_request_cache, new_request_cache
 from floraconcierge.client import ApiClient
 from floraconcierge.errors import ResultObjectNotFoundError, MiddlewareError
@@ -83,7 +84,14 @@ class ApiClientMiddleware(object):
         shortcuts.activate(client)
 
     def process_response(self, request, response):
-        request.session['__floraconcierge_api_env'] = getattr(request, 'apienv', None)
+        if hasattr(request, 'apienv'):
+            # Support api user authentication
+            if isinstance(request.user, User) and request.user.info:
+                request.apienv.user_auth_key = request.user.info.auth.auth_key
+            else:
+                request.apienv.user_auth_key = ''
+
+            request.session['__floraconcierge_api_env'] = request.apienv
 
         return response
 
@@ -118,4 +126,4 @@ class RequestCacheMiddleware(object):
             cache = new_request_cache(self.cache_cls())
 
         cache.clear()
-        request.cache = cache
\ No newline at end of file
+        request.cache = cache
